## 0.7.3.5 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 0.7.3.4 (2023-03-28)

Add defaults for third-party stubs Q-T (#9959)

## 0.7.3.3 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.7.3.2 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 0.7.3.1 (2022-11-21)

Finish `slumber` annotations (#9237)

## 0.7.3 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 0.7.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

